function pValue = kstest2_short(X1,X2)                         % Vectorised two-sample Kolmogorov–Smirnov test over columns
                                                               % Not tested with tied values
                                                               % Short version based on MATLAB's built-in function kstest2

[~, n]  = size(X1);                                            % Number of columns (variables) in the data matrices
pValue  = nan(1,n);                                            % Pre-allocate p-value row vector with NaNs

for c = 1:n                                                    % Loop through each column
    x1 = X1(~isnan(X1(:,c)), c);                               % Sample 1 for column c, with NaNs removed
    x2 = X2(~isnan(X2(:,c)), c);                               % Sample 2 for column c, with NaNs removed

    Nx = numel(x1);                                            % Size of sample 1
    Ny = numel(x2);                                            % Size of sample 2
    if Nx == 0 || Ny == 0                                      % If either sample is empty
        continue                                               % Leave pValue(c) as NaN and skip to next column
    end

    combined = [x1; x2];                                       % Pool the two samples
    [~, idx] = sort(combined);                                 % Sorting indices of pooled data
    labels = [true(Nx,1); false(Ny,1)];                        % Labels: true for x1, false for x2
    labels = labels(idx);                                      % Re-order labels by data rank

    cX = cumsum(labels);                                       % Cumulative count of x1 up to each rank
    cY = cumsum(~labels);                                      % Cumulative count of x2 up to each rank
    cdfDiff = (cX / Nx) - (cY / Ny);                           % Difference between empirical CDFs

    ks = max(abs(cdfDiff));                                    % KS statistic (maximum absolute difference)

    nm = Nx*Ny / (Nx+Ny);                                      % Effective sample size for 2-sample KS approximation
    l = max((sqrt(nm)+0.12+0.11/sqrt(nm)) * ks, 0);            % Scaling factor “l” (Stephens’ correction)
    j = (1:101)';                                              % Series terms 1…101 for p-value approximation
    val = 2 * sum((-1).^(j-1) .* exp(-2*l^2*j.^2));            % Approximate p-value using convergent series
    pValue(c) = min(max(val,0),1);                             % Clamp p-value to [0,1] and store
end
end                                                            % End of function
